@@ -60,6 +60,10 @@
 #define O_CLOEXEC 0
 #endif
 
+#ifndef HAVE_FDATASYNC
+#define fdatasync fsync
+#endif
+
 static char *filename = NULL;
 
 int file_debug_zero;            /* to enable: -D file.zero=1 */
@@ -101,7 +105,8 @@ static int
 file_config_complete (void)
 {
   if (filename == NULL) {
-    nbdkit_error ("you must supply the file=<FILENAME> parameter after the plugin name on the command line");
+    nbdkit_error ("you must supply the file=<FILENAME> parameter "
+                  "after the plugin name on the command line");
     return -1;
   }
 
@@ -476,6 +481,7 @@ static struct nbdkit_plugin plugin = {
   .config            = file_config,
   .config_complete   = file_config_complete,
   .config_help       = file_config_help,
+  .magic_config_key  = "file",
   .dump_plugin       = file_dump_plugin,
   .open              = file_open,
   .close             = file_close,
