@@ -1,5 +1,5 @@
 /* nbdkit
- * Copyright (C) 2017 Red Hat Inc.
+ * Copyright (C) 2017-2018 Red Hat Inc.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -39,10 +39,12 @@
 #include <string.h>
 #include <errno.h>
 
+#define NBDKIT_API_VERSION 2
+
 #include <nbdkit-plugin.h>
 
 /* The size of disk in bytes (initialized by size=<SIZE> parameter). */
-static size_t size = 0;
+static int64_t size = 0;
 
 static int
 null_config (const char *key, const char *value)
@@ -53,11 +55,7 @@ null_config (const char *key, const char *value)
     r = nbdkit_parse_size (value);
     if (r == -1)
       return -1;
-    if (r > SIZE_MAX) {
-      nbdkit_error ("size > SIZE_MAX");
-      return -1;
-    }
-    size = (ssize_t) r;
+    size = r;
   }
   else {
     nbdkit_error ("unknown parameter '%s'", key);
@@ -68,36 +66,15 @@ null_config (const char *key, const char *value)
 }
 
 #define null_config_help \
-  "size=<SIZE>  (required) Size of the backing disk"
-
-/* The per-connection handle. */
-struct null_handle {
-  int readonly;
-};
+  "size=<SIZE>             Size of the backing disk"
 
 /* Create the per-connection handle. */
 static void *
 null_open (int readonly)
 {
-  struct null_handle *h;
+  static int handle;
 
-  h = malloc (sizeof *h);
-  if (h == NULL) {
-    nbdkit_error ("malloc: %m");
-    return NULL;
-  }
-
-  h->readonly = readonly;
-  return h;
-}
-
-/* Free up the per-connection handle. */
-static void
-null_close (void *handle)
-{
-  struct null_handle *h = handle;
-
-  free (h);
+  return &handle;
 }
 
 #define THREAD_MODEL NBDKIT_THREAD_MODEL_PARALLEL
@@ -106,12 +83,13 @@ null_close (void *handle)
 static int64_t
 null_get_size (void *handle)
 {
-  return (int64_t) size;
+  return size;
 }
 
 /* Read data. */
 static int
-null_pread (void *handle, void *buf, uint32_t count, uint64_t offset)
+null_pread (void *handle, void *buf, uint32_t count, uint64_t offset,
+            uint32_t flags)
 {
   memset (buf, 0, count);
   return 0;
@@ -119,40 +97,56 @@ null_pread (void *handle, void *buf, uint32_t count, uint64_t offset)
 
 /* Write data. */
 static int
-null_pwrite (void *handle, const void *buf, uint32_t count, uint64_t offset)
+null_pwrite (void *handle, const void *buf, uint32_t count, uint64_t offset,
+             uint32_t flags)
 {
   /* nothing */
   return 0;
 }
 
+/* Write zeros. */
 static int
-null_can_write (void *handle)
-{
-  struct null_handle *h = handle;
-
-  return !h->readonly;
-}
-
-/* Write zeroes - very efficient! */
-static int
-null_zero (void *handle, uint32_t count, uint64_t offset, int may_trim)
+null_zero (void *handle, uint32_t count, uint64_t offset, uint32_t flags)
 {
   /* nothing */
   return 0;
 }
 
+/* Flush is a no-op, so advertise native FUA support */
+static int
+null_can_fua (void *handle)
+{
+  return NBDKIT_FUA_NATIVE;
+}
+
+/* Trim. */
+static int
+null_trim (void *handle, uint32_t count, uint64_t offset, uint32_t flags)
+{
+  /* nothing */
+  return 0;
+}
+
+/* Nothing is persistent, so flush is trivially supported */
+static int
+null_flush (void *handle, uint32_t flags)
+{
+  return 0;
+}
+
 static struct nbdkit_plugin plugin = {
   .name              = "null",
   .version           = PACKAGE_VERSION,
   .config            = null_config,
   .config_help       = null_config_help,
   .open              = null_open,
-  .close             = null_close,
   .get_size          = null_get_size,
   .pread             = null_pread,
   .pwrite            = null_pwrite,
-  .can_write         = null_can_write,
   .zero              = null_zero,
+  .trim              = null_trim,
+  .can_fua           = null_can_fua,
+  .flush             = null_flush,
   /* In this plugin, errno is preserved properly along error return
    * paths from failed system calls.
    */
