@@ -78,13 +78,13 @@ struct connection {
   uint32_t cflags;
   uint64_t exportsize;
   uint16_t eflags;
-  int readonly;
-  int can_flush;
-  int is_rotational;
-  int can_trim;
-  int can_zero;
-  int can_fua;
-  int using_tls;
+  bool readonly;
+  bool can_flush;
+  bool is_rotational;
+  bool can_trim;
+  bool can_zero;
+  bool can_fua;
+  bool using_tls;
 
   int sockin, sockout;
   connection_recv_function recv;
@@ -419,7 +419,7 @@ compute_eflags (struct connection *conn, uint16_t *flags)
     return -1;
   if (readonly || !fl) {
     eflags |= NBD_FLAG_READ_ONLY;
-    conn->readonly = 1;
+    conn->readonly = true;
   }
   if (!conn->readonly) {
     fl = backend->can_zero (backend, conn);
@@ -427,7 +427,7 @@ compute_eflags (struct connection *conn, uint16_t *flags)
       return -1;
     if (fl) {
       eflags |= NBD_FLAG_SEND_WRITE_ZEROES;
-      conn->can_zero = 1;
+      conn->can_zero = true;
     }
 
     fl = backend->can_trim (backend, conn);
@@ -435,7 +435,7 @@ compute_eflags (struct connection *conn, uint16_t *flags)
       return -1;
     if (fl) {
       eflags |= NBD_FLAG_SEND_TRIM;
-      conn->can_trim = 1;
+      conn->can_trim = true;
     }
 
     fl = backend->can_fua (backend, conn);
@@ -443,7 +443,7 @@ compute_eflags (struct connection *conn, uint16_t *flags)
       return -1;
     if (fl) {
       eflags |= NBD_FLAG_SEND_FUA;
-      conn->can_fua = 1;
+      conn->can_fua = true;
     }
   }
 
@@ -452,7 +452,7 @@ compute_eflags (struct connection *conn, uint16_t *flags)
     return -1;
   if (fl) {
     eflags |= NBD_FLAG_SEND_FLUSH;
-    conn->can_flush = 1;
+    conn->can_flush = true;
   }
 
   fl = backend->is_rotational (backend, conn);
@@ -460,7 +460,7 @@ compute_eflags (struct connection *conn, uint16_t *flags)
     return -1;
   if (fl) {
     eflags |= NBD_FLAG_ROTATIONAL;
-    conn->is_rotational = 1;
+    conn->is_rotational = true;
   }
 
   *flags = eflags;
@@ -600,6 +600,31 @@ send_newstyle_option_reply_info_export (struct connection *conn,
   return 0;
 }
 
+/* Sub-function during _negotiate_handshake_newstyle, to uniformly handle
+ * a client hanging up on a message boundary.
+ */
+static int __attribute__ ((format (printf, 4, 5)))
+conn_recv_full (struct connection *conn, void *buf, size_t len,
+                const char *fmt, ...)
+{
+  int r = conn->recv (conn, buf, len);
+  va_list args;
+
+  if (r == -1) {
+    va_start (args, fmt);
+    nbdkit_verror (fmt, args);
+    va_end (args);
+    return -1;
+  }
+  if (r == 0) {
+    /* During negotiation, client EOF on message boundary is less
+     * severe than failure in the middle of the buffer. */
+    debug ("client closed input socket, closing connection");
+    return -1;
+  }
+  return r;
+}
+
 /* Sub-function of _negotiate_handshake_newstyle_options below.  It
  * must be called on all non-error paths out of the options for-loop
  * in that function.
@@ -638,10 +663,9 @@ _negotiate_handshake_newstyle_options (struct connection *conn)
   struct new_handshake_finish handshake_finish;
 
   for (nr_options = 0; nr_options < MAX_NR_OPTIONS; ++nr_options) {
-    if (conn->recv (conn, &new_option, sizeof new_option) == -1) {
-      nbdkit_error ("read: %m");
+    if (conn_recv_full (conn, &new_option, sizeof new_option,
+                        "reading option: conn->recv: %m") == -1)
       return -1;
-    }
 
     version = be64toh (new_option.version);
     if (version != NEW_VERSION) {
@@ -674,10 +698,9 @@ _negotiate_handshake_newstyle_options (struct connection *conn)
 
     switch (option) {
     case NBD_OPT_EXPORT_NAME:
-      if (conn->recv (conn, data, optlen) == -1) {
-        nbdkit_error ("read: %m");
+      if (conn_recv_full (conn, data, optlen,
+                          "read: %m") == -1)
         return -1;
-      }
       /* Apart from printing it, ignore the export name. */
       data[optlen] = '\0';
       debug ("newstyle negotiation: NBD_OPT_EXPORT_NAME: "
@@ -713,10 +736,9 @@ _negotiate_handshake_newstyle_options (struct connection *conn)
         if (send_newstyle_option_reply (conn, option, NBD_REP_ERR_INVALID)
             == -1)
           return -1;
-        if (conn->recv (conn, data, optlen) == -1) {
-          nbdkit_error ("read: %m");
+        if (conn_recv_full (conn, data, optlen,
+                            "read: %m") == -1)
           return -1;
-        }
         continue;
       }
 
@@ -735,10 +757,9 @@ _negotiate_handshake_newstyle_options (struct connection *conn)
         if (send_newstyle_option_reply (conn, option, NBD_REP_ERR_INVALID)
             == -1)
           return -1;
-        if (conn->recv (conn, data, optlen) == -1) {
-          nbdkit_error ("read: %m");
+        if (conn_recv_full (conn, data, optlen,
+                            "read: %m") == -1)
           return -1;
-        }
         continue;
       }
 
@@ -769,16 +790,15 @@ _negotiate_handshake_newstyle_options (struct connection *conn)
         /* Upgrade the connection to TLS.  Also performs access control. */
         if (crypto_negotiate_tls (conn, conn->sockin, conn->sockout) == -1)
           return -1;
-        conn->using_tls = 1;
+        conn->using_tls = true;
         debug ("using TLS on this connection");
       }
       break;
 
     case NBD_OPT_GO:
-      if (conn->recv (conn, data, optlen) == -1) {
-        nbdkit_error ("read: %m");
+      if (conn_recv_full (conn, data, optlen,
+                          "read: %m") == -1)
         return -1;
-      }
 
       if (optlen < 6) { /* 32 bit export length + 16 bit nr info */
         debug ("newstyle negotiation: NBD_OPT_GO option length < 6");
@@ -874,10 +894,9 @@ _negotiate_handshake_newstyle_options (struct connection *conn)
       /* Unknown option. */
       if (send_newstyle_option_reply (conn, option, NBD_REP_ERR_UNSUP) == -1)
         return -1;
-      if (conn->recv (conn, data, optlen) == -1) {
-        nbdkit_error ("read: %m");
+      if (conn_recv_full (conn, data, optlen,
+                          "reading unknown option data: conn->recv: %m") == -1)
         return -1;
-      }
     }
 
     /* Note, since it's not very clear from the protocol doc, that the
@@ -925,10 +944,9 @@ _negotiate_handshake_newstyle (struct connection *conn)
   }
 
   /* Client now sends us its 32 bit flags word ... */
-  if (conn->recv (conn, &conn->cflags, sizeof conn->cflags) == -1) {
-    nbdkit_error ("read: %m");
+  if (conn_recv_full (conn, &conn->cflags, sizeof conn->cflags,
+                      "reading initial client flags: conn->recv: %m") == -1)
     return -1;
-  }
   conn->cflags = be32toh (conn->cflags);
   /* ... which we check for accuracy. */
   debug ("newstyle negotiation: client flags: 0x%x", conn->cflags);
