@@ -134,19 +134,22 @@ static void
 filter_usage (struct backend *b)
 {
   struct backend_filter *f = container_of (b, struct backend_filter, backend);
+  const char *p;
 
   printf ("filter: %s", f->name);
   if (f->filter.longname)
     printf (" (%s)", f->filter.longname);
   printf ("\n");
-  printf ("(%s)", f->filename);
+  printf ("(%s)\n", f->filename);
   if (f->filter.description) {
-    printf ("\n");
-    printf ("%s\n", f->filter.description);
+    printf ("%s", f->filter.description);
+    if ((p = strrchr (f->filter.description, '\n')) == NULL || p[1])
+      printf ("\n");
   }
   if (f->filter.config_help) {
-    printf ("\n");
-    printf ("%s\n", f->filter.config_help);
+    printf ("%s", f->filter.config_help);
+    if ((p = strrchr (f->filter.config_help, '\n')) == NULL || p[1])
+      printf ("\n");
   }
 }
 
@@ -205,6 +208,17 @@ filter_config_complete (struct backend *b)
     f->backend.next->config_complete (f->backend.next);
 }
 
+/* magic_config_key only applies to plugins, so this passes the
+ * request through to the plugin (hence the name).
+ */
+static const char *
+plugin_magic_config_key (struct backend *b)
+{
+  struct backend_filter *f = container_of (b, struct backend_filter, backend);
+
+  return f->backend.next->magic_config_key (f->backend.next);
+}
+
 static int
 next_open (void *nxdata, int readonly)
 {
@@ -619,6 +633,7 @@ static struct backend filter_functions = {
   .dump_fields = filter_dump_fields,
   .config = filter_config,
   .config_complete = filter_config_complete,
+  .magic_config_key = plugin_magic_config_key,
   .open = filter_open,
   .prepare = filter_prepare,
   .finalize = filter_finalize,
@@ -677,7 +692,9 @@ filter_register (struct backend *next, size_t index, const char *filename,
    * mismatch when the API changes.
    */
   if (filter->_api_version != NBDKIT_FILTER_API_VERSION) {
-    fprintf (stderr, "%s: %s: filter is incompatible with this version of nbdkit (_api_version = %d)\n",
+    fprintf (stderr,
+             "%s: %s: filter is incompatible with this version of nbdkit "
+             "(_api_version = %d)\n",
              program_name, f->filename, filter->_api_version);
     exit (EXIT_FAILURE);
   }
@@ -701,7 +718,9 @@ filter_register (struct backend *next, size_t index, const char *filename,
     if (!((f->filter.name[i] >= '0' && f->filter.name[i] <= '9') ||
           (f->filter.name[i] >= 'a' && f->filter.name[i] <= 'z') ||
           (f->filter.name[i] >= 'A' && f->filter.name[i] <= 'Z'))) {
-      fprintf (stderr, "%s: %s: filter.name ('%s') field must contain only ASCII alphanumeric characters\n",
+      fprintf (stderr,
+               "%s: %s: filter.name ('%s') field "
+               "must contain only ASCII alphanumeric characters\n",
                program_name, f->filename, f->filter.name);
       exit (EXIT_FAILURE);
     }
