@@ -103,19 +103,22 @@ static void
 plugin_usage (struct backend *b)
 {
   struct backend_plugin *p = container_of (b, struct backend_plugin, backend);
+  const char *t;
 
   printf ("plugin: %s", p->name);
   if (p->plugin.longname)
     printf (" (%s)", p->plugin.longname);
   printf ("\n");
-  printf ("(%s)", p->filename);
+  printf ("(%s)\n", p->filename);
   if (p->plugin.description) {
-    printf ("\n");
-    printf ("%s\n", p->plugin.description);
+    printf ("%s", p->plugin.description);
+    if ((t = strrchr (p->plugin.description, '\n')) == NULL || t[1])
+      printf ("\n");
   }
   if (p->plugin.config_help) {
-    printf ("\n");
-    printf ("%s\n", p->plugin.config_help);
+    printf ("%s", p->plugin.config_help);
+    if ((t = strrchr (p->plugin.config_help, '\n')) == NULL || t[1])
+      printf ("\n");
   }
 }
 
@@ -164,6 +167,8 @@ plugin_dump_fields (struct backend *b)
   }
   printf ("\n");
   printf ("errno_is_preserved=%d\n", p->plugin.errno_is_preserved);
+  if (p->plugin.magic_config_key)
+    printf ("magic_config_key=%s\n", p->plugin.magic_config_key);
 
 #define HAS(field) if (p->plugin.field) printf ("has_%s=1\n", #field)
   HAS (longname);
@@ -207,7 +212,8 @@ plugin_config (struct backend *b, const char *key, const char *value)
   debug ("%s: config key=%s, value=%s", p->name, key, value);
 
   if (p->plugin.config == NULL) {
-    fprintf (stderr, "%s: %s: this plugin does not need command line configuration\n"
+    fprintf (stderr,
+             "%s: %s: this plugin does not need command line configuration\n"
              "Try using: %s --help %s\n",
              program_name, p->filename,
              program_name, p->filename);
@@ -232,6 +238,14 @@ plugin_config_complete (struct backend *b)
     exit (EXIT_FAILURE);
 }
 
+static const char *
+plugin_magic_config_key (struct backend *b)
+{
+  struct backend_plugin *p = container_of (b, struct backend_plugin, backend);
+
+  return p->plugin.magic_config_key;
+}
+
 static int
 plugin_open (struct backend *b, struct connection *conn, int readonly)
 {
@@ -630,6 +644,7 @@ static struct backend plugin_functions = {
   .dump_fields = plugin_dump_fields,
   .config = plugin_config,
   .config_complete = plugin_config_complete,
+  .magic_config_key = plugin_magic_config_key,
   .open = plugin_open,
   .prepare = plugin_prepare,
   .finalize = plugin_finalize,
@@ -685,7 +700,9 @@ plugin_register (size_t index, const char *filename,
 
   /* Check for incompatible future versions. */
   if (plugin->_api_version < 0 || plugin->_api_version > 2) {
-    fprintf (stderr, "%s: %s: plugin is incompatible with this version of nbdkit (_api_version = %d)\n",
+    fprintf (stderr,
+             "%s: %s: plugin is incompatible with this version of nbdkit "
+             "(_api_version = %d)\n",
              program_name, p->filename, plugin->_api_version);
     exit (EXIT_FAILURE);
   }
@@ -735,7 +752,9 @@ plugin_register (size_t index, const char *filename,
     if (!((p->plugin.name[i] >= '0' && p->plugin.name[i] <= '9') ||
           (p->plugin.name[i] >= 'a' && p->plugin.name[i] <= 'z') ||
           (p->plugin.name[i] >= 'A' && p->plugin.name[i] <= 'Z'))) {
-      fprintf (stderr, "%s: %s: plugin.name ('%s') field must contain only ASCII alphanumeric characters\n",
+      fprintf (stderr,
+               "%s: %s: plugin.name ('%s') field "
+               "must contain only ASCII alphanumeric characters\n",
                program_name, p->filename, p->plugin.name);
       exit (EXIT_FAILURE);
     }
@@ -794,7 +813,7 @@ set_debug_flags (void *dl, const char *name)
       *sym = flag->value;
 
       /* Mark this flag as used. */
-      flag->used = 1;
+      flag->used = true;
     }
   }
 }
