@@ -31,6 +31,7 @@
 # OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 # SUCH DAMAGE.
 
+source ./functions.sh
 set -e
 
 output="$(nbdkit --help)"
@@ -39,3 +40,25 @@ if [[ ! ( "$output" =~ dump-config ) ]]; then
     echo "$output"
     exit 1
 fi
+
+# Run nbdkit plugin --help for each plugin.
+# However some of these tests are expected to fail.
+test ()
+{
+    vg=; [ "$NBDKIT_VALGRIND" = "1" ] && vg="-valgrind"
+    case "$1$vg" in
+        vddk | vddk-valgrind)
+            # VDDK won't run without special environment variables
+            # being set, so ignore it.
+            ;;
+        lua-valgrind | perl-valgrind | python-valgrind | \
+        ruby-valgrind | tcl-valgrind | \
+        example4-valgrind | tar-valgrind)
+            # Plugins written in scripting languages can't run under valgrind.
+            ;;
+        *)
+            nbdkit $1 --help
+            ;;
+    esac
+}
+foreach_plugin test
