@@ -152,6 +152,12 @@ main (int argc, char *argv[])
     perror ("pthread_create");
     exit (EXIT_FAILURE);
   }
+  err = pthread_detach (thread);
+  if (err) {
+    errno = err;
+    perror ("pthread_detach");
+    exit (EXIT_FAILURE);
+  }
 
   /* Note for the purposes of this test we're not very careful about
    * checking for errors (except for the bare minimum) or handling the
@@ -231,7 +237,8 @@ main (int argc, char *argv[])
     exit (EXIT_FAILURE);
   }
   if ((eflags & NBD_FLAG_SEND_WRITE_ZEROES) == 0) {
-    fprintf (stderr, "%s: unexpected eflags: NBD_FLAG_SEND_WRITE_ZEROES not set\n",
+    fprintf (stderr,
+             "%s: unexpected eflags: NBD_FLAG_SEND_WRITE_ZEROES not set\n",
              program_name);
     exit (EXIT_FAILURE);
   }
